import { BaseRealm } from '@yukawa/chain-base-angular-domain';
import { ɵɵinject, forwardRef, ɵɵdefineInjectable, ɵsetClassMetadata, Injectable, Inject, ɵɵdefineNgModule, ɵɵdefineInjector, ɵɵsetNgModuleScope, NgModule, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import { HttpHeaders, HttpClient, HttpParams, HttpClientModule } from '@angular/common/http';
import { map } from 'rxjs/operators';
import { RestAspect, ConfigService, RepoAspectRest } from '@yukawa/chain-base-angular-client';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { FlexLayoutModule } from '@angular/flex-layout';
import { TranslateModule } from '@ngx-translate/core';
import { MatButtonModule } from '@angular/material/button';
import { MatIconModule } from '@angular/material/icon';
import { MatRippleModule } from '@angular/material/core';
import { MatSlideToggleModule } from '@angular/material/slide-toggle';
import { MatTableModule } from '@angular/material/table';
import { MatSortModule } from '@angular/material/sort';
import { MatTooltipModule } from '@angular/material/tooltip';
import { MatMenuModule } from '@angular/material/menu';
import { MatCheckboxModule } from '@angular/material/checkbox';

// noinspection JSUnusedGlobalSymbols
/**
 * inc.yukawa.tracker.base.core.realm.TrackerRealm
 * @since 2.0.7
 **/
class TrackerRealm extends BaseRealm {
}

var ProjectPhase;
(function (ProjectPhase) {
    ProjectPhase["PHASE_PROJECT"] = "project";
    ProjectPhase["PHASE_LEAD"] = "lead";
    ProjectPhase["PHASE_PROPOSAL"] = "proposal";
})(ProjectPhase || (ProjectPhase = {}));
var Fep;
(function (Fep) {
    Fep["NEW"] = "NEW";
    Fep["REJECTED"] = "REJECTED";
    Fep["WAIT_FOR_CONFIRM"] = "WAIT_FOR_CONFIRM";
    Fep["CONFIRMED"] = "CONFIRMED";
})(Fep || (Fep = {}));
var AttachmentCategory;
(function (AttachmentCategory) {
    AttachmentCategory["INVOICE"] = "INVOICE";
})(AttachmentCategory || (AttachmentCategory = {}));
const projectPhases = [];
for (let n in ProjectPhase) {
    if (typeof ProjectPhase[n] === 'string') {
        projectPhases.push(ProjectPhase[n]);
    }
}
class Yukawa_LeanRealm extends TrackerRealm {
}
Yukawa_LeanRealm.ROLE_INVOICE_FEP_CONFIRM_PARTIAL = "ROLE_INVOICE_FEP_CONFIRM_PARTIAL";
Yukawa_LeanRealm.ROLE_INVOICE_FEP_REJECT = "ROLE_INVOICE_FEP_REJECT";
Yukawa_LeanRealm.ROLE_INVOICE_FEP_CONFIRM = "ROLE_INVOICE_FEP_CONFIRM";

class TaskUtils {
    /**
     * This function calculates the price/volume of a list of tasks
     *
     * @param subTasks List of tasks
     * @param projectRoles List of project roles containing the prices
     */
    static calculatePrice(subTasks, projectRoles) {
        let result = 0;
        for (let task of subTasks) {
            let hourlyRate = task.role.hourlyRate;
            let frequency = task.plannedBudget.amount;
            if (hourlyRate && frequency) {
                result += hourlyRate * frequency;
            }
        }
        return result;
    }
    static getProjectRoleHourlyRateMap(roles) {
        let dict = {};
        for (let role of roles) {
            dict[role.roleId] = role.hourlyRate;
        }
        return dict;
    }
}

class ProjectService extends RestAspect {
    constructor(http, configService) {
        super(http, configService, configService.formatUrl("projectUrl"));
    }
    // searchProject(filter: any): Observable<SearchResult<Project>> {
    //     return this.search<Project>(this.formatServiceUrl('/search'), filter);
    // }
    queryProject(filter) {
        return this.query(this.formatServiceUrl('/query'), filter);
    }
    loadProject(id) {
        return this.load(`${this.formatServiceUrl('')}?key=${id}`)
            .pipe(map(value => this.checkNotNull(value)));
    }
    saveProject(project, type = "create") {
        return this.edit(this.formatServiceUrl(`/${type}`), project, { method: 'post' });
    }
    deleteProject(id) {
        return this.http.delete(`${this.formatServiceUrl('')}/?key=${id}`);
    }
    updateProjectPhase(phase, projectId) {
        return this.http.post(`${this.formatServiceUrl('/phase')}?projectId=${projectId}`, phase);
    }
    newProject() {
        return this.http.post(`${this.formatServiceUrl('/new')}`, {})
            .pipe(map(value => this.checkNotNull(value)));
    }
    downloadPdf(projectId) {
        return this.http.post(`${this.formatServiceUrl('/generateProposal')}`, projectId);
    }
    export(filter) {
        let opts = {
            headers: new HttpHeaders({
                'Content-Type': 'application/json'
                //'Accept': 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
            })
        };
        return this.download(`${this.formatServiceUrl('/export')}`, filter, opts);
    }
}
/** @nocollapse */ ProjectService.ɵfac = function ProjectService_Factory(t) { return new (t || ProjectService)(ɵɵinject(forwardRef(() => HttpClient)), ɵɵinject(forwardRef(() => ConfigService))); };
/** @nocollapse */ ProjectService.ɵprov = ɵɵdefineInjectable({ token: ProjectService, factory: ProjectService.ɵfac });
/*@__PURE__*/ (function () { ɵsetClassMetadata(ProjectService, [{
        type: Injectable
    }], function () { return [{ type: HttpClient, decorators: [{
                type: Inject,
                args: [forwardRef(() => HttpClient)]
            }] }, { type: ConfigService, decorators: [{
                type: Inject,
                args: [forwardRef(() => ConfigService)]
            }] }]; }, null); })();
class TaskService extends RestAspect {
    constructor(http, configService) {
        super(http, configService, configService.formatUrl("taskUrl"));
    }
    // searchTask(filter: any): Observable<SearchResult<Task>> {
    //     return this.search<Project>(this.formatServiceUrl('/search'), filter);
    // }
    queryTask(filter) {
        return this.query(this.formatServiceUrl('/query'), filter);
    }
    loadTask(id) {
        return this.load(`${this.formatServiceUrl('')}?key=${id}`)
            .pipe(map(value => this.checkNotNull(value)));
    }
    saveTask(task, type = "create") {
        return this.edit(this.formatServiceUrl(`/${type}`), task, { method: 'post' });
    }
    mergeTask(task) {
        return this.edit(this.formatServiceUrl(`/merge`), task, { method: 'post' });
    }
    deleteTask(id) {
        return this.http.delete(`${this.formatServiceUrl()}/?key=${id}`);
    }
    generateInvoice(invoice) {
        return this.http.post(this.formatServiceUrl('/generateInvoice'), invoice);
    }
}
/** @nocollapse */ TaskService.ɵfac = function TaskService_Factory(t) { return new (t || TaskService)(ɵɵinject(forwardRef(() => HttpClient)), ɵɵinject(forwardRef(() => ConfigService))); };
/** @nocollapse */ TaskService.ɵprov = ɵɵdefineInjectable({ token: TaskService, factory: TaskService.ɵfac, providedIn: 'root' });
/*@__PURE__*/ (function () { ɵsetClassMetadata(TaskService, [{
        type: Injectable,
        args: [{
                providedIn: 'root'
            }]
    }], function () { return [{ type: HttpClient, decorators: [{
                type: Inject,
                args: [forwardRef(() => HttpClient)]
            }] }, { type: ConfigService, decorators: [{
                type: Inject,
                args: [forwardRef(() => ConfigService)]
            }] }]; }, null); })();
class ProjectSheetService extends RestAspect {
    constructor(http, configService) {
        super(http, configService, configService.formatUrl("projectSheetUrl"));
    }
    // searchProjectSheet(filter: any): Observable<SearchResult<ProjectSheet>> {
    //     return this.search<ProjectSheet>(this.formatServiceUrl('/search'), filter);
    // }
    queryProjectSheet(filter) {
        return this.query(this.formatServiceUrl('/query'), filter);
    }
    loadProjectSheet(id) {
        return this.load(`${this.formatServiceUrl('')}/?key=${id}`)
            .pipe(map(value => this.checkNotNull(value)));
    }
    saveProjectSheet(task, type = "create") {
        return this.edit(this.formatServiceUrl(`/${type}`), task, { method: 'post' });
    }
    deleteProjectSheet(id) {
        return this.http.delete(`${this.formatServiceUrl()}/?key=${id}`);
    }
}
/** @nocollapse */ ProjectSheetService.ɵfac = function ProjectSheetService_Factory(t) { return new (t || ProjectSheetService)(ɵɵinject(forwardRef(() => HttpClient)), ɵɵinject(forwardRef(() => ConfigService))); };
/** @nocollapse */ ProjectSheetService.ɵprov = ɵɵdefineInjectable({ token: ProjectSheetService, factory: ProjectSheetService.ɵfac });
/*@__PURE__*/ (function () { ɵsetClassMetadata(ProjectSheetService, [{
        type: Injectable
    }], function () { return [{ type: HttpClient, decorators: [{
                type: Inject,
                args: [forwardRef(() => HttpClient)]
            }] }, { type: ConfigService, decorators: [{
                type: Inject,
                args: [forwardRef(() => ConfigService)]
            }] }]; }, null); })();
class RiskService extends RestAspect {
    constructor(http, configService) {
        super(http, configService, configService.formatUrl("risksUrl"));
    }
    searchRisk(filter) {
        return this.search(this.formatServiceUrl('/search'), filter);
    }
    queryRisks(filter) {
        return this.query(this.formatServiceUrl('/query'), filter);
    }
    loadRisk(id) {
        return this.load(`${this.formatServiceUrl('')}/?key=${id}`)
            .pipe(map(value => this.checkNotNull(value)));
    }
    saveRisk(task, type = "create") {
        return this.edit(this.formatServiceUrl(`/${type}`), task, { method: 'post' });
    }
    deleteRisk(id) {
        return this.http.delete(`${this.formatServiceUrl()}/?key=${id}`);
    }
}
/** @nocollapse */ RiskService.ɵfac = function RiskService_Factory(t) { return new (t || RiskService)(ɵɵinject(forwardRef(() => HttpClient)), ɵɵinject(forwardRef(() => ConfigService))); };
/** @nocollapse */ RiskService.ɵprov = ɵɵdefineInjectable({ token: RiskService, factory: RiskService.ɵfac, providedIn: 'root' });
/*@__PURE__*/ (function () { ɵsetClassMetadata(RiskService, [{
        type: Injectable,
        args: [{
                providedIn: 'root'
            }]
    }], function () { return [{ type: HttpClient, decorators: [{
                type: Inject,
                args: [forwardRef(() => HttpClient)]
            }] }, { type: ConfigService, decorators: [{
                type: Inject,
                args: [forwardRef(() => ConfigService)]
            }] }]; }, null); })();

class AttachmentService extends RepoAspectRest {
    constructor(http, configService) {
        super(http, configService, 'attachmentUrl');
    }
    download(id, version) {
        return this.http.get(this.formatServiceUrl('/download/' + id), {
            responseType: 'blob'
        });
    }
    upload(attachment) {
        // @toDo * [ww] impl
        throw new Error('upload not implemented');
    }
    confirmAttachment(id) {
        return this.http.post(`${this.formatServiceUrl()}/fep/confirm?attachmentId=${id}`, null);
    }
    rejectAttachment(id) {
        return this.http.post(`${this.formatServiceUrl()}/fep/reject?attachmentId=${id}`, null);
    }
    // @toDo remove later
    deleteByKey(key) {
        // overloaded for this.formatServiceUrl('/')
        const queryParamsList = [];
        if (key !== undefined && key !== null) {
            queryParamsList.push({ name: 'key', value: key.toString() });
        }
        let params = new HttpParams();
        for (const queryParam of queryParamsList) {
            params = params.append(queryParam.name, queryParam.value);
        }
        return this.http.delete(this.formatServiceUrl('/'), { params });
    }
}
/** @nocollapse */ AttachmentService.ɵfac = function AttachmentService_Factory(t) { return new (t || AttachmentService)(ɵɵinject(forwardRef(() => HttpClient)), ɵɵinject(forwardRef(() => ConfigService))); };
/** @nocollapse */ AttachmentService.ɵprov = ɵɵdefineInjectable({ token: AttachmentService, factory: AttachmentService.ɵfac, providedIn: "root" });
/*@__PURE__*/ (function () { ɵsetClassMetadata(AttachmentService, [{
        type: Injectable,
        args: [{ providedIn: "root" }]
    }], function () { return [{ type: HttpClient, decorators: [{
                type: Inject,
                args: [forwardRef(() => HttpClient)]
            }] }, { type: ConfigService, decorators: [{
                type: Inject,
                args: [forwardRef(() => ConfigService)]
            }] }]; }, null); })();

// modules
// services
class CoreModule {
    static forRoot() {
        return {
            ngModule: CoreModule,
            providers: [
                ProjectService, ProjectSheetService, TaskService, AttachmentService, RiskService
            ]
        };
    }
}
/** @nocollapse */ CoreModule.ɵmod = ɵɵdefineNgModule({ type: CoreModule });
/** @nocollapse */ CoreModule.ɵinj = ɵɵdefineInjector({ factory: function CoreModule_Factory(t) { return new (t || CoreModule)(); }, providers: [], imports: [[
            CommonModule,
            FormsModule,
            MatButtonModule,
            MatIconModule,
            MatRippleModule,
            MatSlideToggleModule,
            MatTableModule,
            MatSortModule,
            MatTooltipModule,
            FlexLayoutModule,
            MatMenuModule,
            MatCheckboxModule,
            HttpClientModule,
            TranslateModule.forChild()
        ]] });
(function () { (typeof ngJitMode === "undefined" || ngJitMode) && ɵɵsetNgModuleScope(CoreModule, { imports: [CommonModule,
        FormsModule,
        MatButtonModule,
        MatIconModule,
        MatRippleModule,
        MatSlideToggleModule,
        MatTableModule,
        MatSortModule,
        MatTooltipModule,
        FlexLayoutModule,
        MatMenuModule,
        MatCheckboxModule,
        HttpClientModule, TranslateModule] }); })();
/*@__PURE__*/ (function () { ɵsetClassMetadata(CoreModule, [{
        type: NgModule,
        args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    MatButtonModule,
                    MatIconModule,
                    MatRippleModule,
                    MatSlideToggleModule,
                    MatTableModule,
                    MatSortModule,
                    MatTooltipModule,
                    FlexLayoutModule,
                    MatMenuModule,
                    MatCheckboxModule,
                    HttpClientModule,
                    TranslateModule.forChild()
                ],
                declarations: [],
                exports: [],
                providers: [],
                entryComponents: [],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            }]
    }], null, null); })();

// Managers

/**
 * Generated bundle index. Do not edit.
 */

export { AttachmentCategory, AttachmentService, CoreModule, Fep, ProjectPhase, ProjectService, ProjectSheetService, RiskService, TaskService, TaskUtils, TrackerRealm, Yukawa_LeanRealm, projectPhases };
//# sourceMappingURL=yukawa-chain-tracker-angular-core.js.map
