import { Change, Changed, Created, FileInfo, Info, Organized } from '@yukawa/chain-base-angular-domain';
/**
*	@generator rest2ts
*	javaType: inc.yukawa.tracker.base.core.domain.Attachment <br/>
*/
export interface Attachment extends Changed, Created, Organized {
    attachmentId?: string;
    category?: string;
    change?: Change;
    created?: Change;
    fepStatus?: FepStatus;
    file?: FileInfo;
    orgId?: string;
    preview?: FileInfo;
    projectId?: string;
    taskId?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.tracker.base.core.domain.Budget <br/>
*/
export interface Budget {
    amount?: number;
    money?: number;
    time?: number;
    unit?: string;
    unitPrice?: number;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.tracker.base.core.domain.Comment <br/>
*/
export interface Comment extends Changed, Organized {
    change?: Change;
    commentId?: string;
    orgId?: string;
    personId?: string;
    value?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.tracker.base.core.domain.CustomField <br/>
*/
export interface CustomField {
    name?: string;
    required?: boolean;
    type?: string;
    value?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.tracker.base.core.domain.FepStatus <br/>
*/
export interface FepStatus extends Changed {
    change?: Change;
    comment?: string;
    /**
    *	values: WAIT_FOR_CONFIRM, NEW, CONFIRMED, REJECTED<br/>
    */
    status?: string;
    userIds?: string[];
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.tracker.base.core.domain.FinanceInfo <br/>
*/
export interface FinanceInfo extends Organized {
    orgId?: string;
    parentAccountName?: string;
    scenarioNames?: string[];
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.tracker.base.core.domain.Goals <br/>
*/
export interface Goals {
    approach?: string;
    collaboration?: string;
    goal?: string;
    initialSituation?: string;
    partialGoals?: string;
    results?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.tracker.base.core.domain.NextStep <br/>
*/
export interface NextStep {
    dueDate?: Date;
    info?: Info;
    responsiblePartnerId?: string;
    taskId?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.tracker.base.core.domain.PartnerInfo <br/>
*/
export interface PartnerInfo {
    companyName?: string;
    email?: string;
    firstName?: string;
    lastName?: string;
    partnerId?: string;
    partnerType?: string;
    shortName?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.tracker.base.core.domain.Project <br/>
*/
export interface Project extends Task {
    /**
    *	@example Dienstleistung
    */
    contractType?: string;
    costScenarioIds?: string[];
    customer?: PartnerInfo;
    flatPrice?: number;
    head?: PartnerInfo;
    isFlatPrice?: boolean;
    language?: string;
    lead?: PartnerInfo;
    offerValidUntil?: Date;
    /**
    *	@example Zahlbar nach 2 Wochen ohne Skonto
    */
    paymentConditions?: string;
    /**
    *	values: lead,proposal,project<br/>
    *	@example lead
    */
    phase?: string;
    roles?: ProjectRole[];
    /**
    *	@example Fuer die Bearbeitung des Projektes wird eine Zeitdauer von 1 Monat angesetzt. Die Arbeiten koennen unmittelbar nach Beauftragung begonnen werden.
    */
    timeFrame?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.tracker.base.core.domain.ProjectRole <br/>
*/
export interface ProjectRole {
    hourlyRate?: number;
    name?: string;
    roleId?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.tracker.base.core.domain.ProjectSheet <br/>
*/
export interface ProjectSheet extends Changed, Created, Organized {
    budget?: Budget;
    change?: Change;
    created?: Change;
    info?: Info;
    nextSteps?: NextStep[];
    orgId?: string;
    percentageOfCompletion?: number;
    projectId?: string;
    projectSheetId?: string;
    reportDate?: Date;
    /**
    *	values: green, yellow, red<br/>
    *	@example green
    */
    status?: string;
    /**
    *	values: internal, external<br/>
    *	@example internal
    */
    type?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.tracker.base.core.domain.Risk <br/>
*/
export interface Risk extends Changed, Created, Organized {
    change?: Change;
    created?: Change;
    dueDate?: Date;
    mitigation?: string;
    name?: string;
    orgId?: string;
    /**
    *	values: low, medium, high<br/>
    *	@example low
    */
    probability?: string;
    projectId?: string;
    responsiblePartnerId?: string;
    riskId?: string;
    /**
    *	values: low, medium, high<br/>
    *	@example low
    */
    severity?: string;
    /**
    *	values: open, closed<br/>
    *	@example closed
    */
    status?: string;
    taskId?: string;
}
/**
*	@deprecated
*	@generator rest2ts
*	javaType: inc.yukawa.tracker.base.core.domain.SubContract <br/>
*/
export interface SubContract {
    contractor?: PartnerInfo;
    notes?: string;
    projectId?: string;
    volume?: number;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.tracker.base.core.domain.Task <br/>
*/
export interface Task extends Changed, Created, Organized {
    actualBudget?: Budget;
    actualEndDate?: Date;
    actualStartDate?: Date;
    actualSubBudget?: Budget;
    assignedUserIds?: string[];
    attachments?: Attachment[];
    change?: Change;
    comments?: Comment[];
    contactLogIds?: string[];
    costCenterId?: string;
    created?: Change;
    customFields?: CustomField[];
    duration?: number;
    /**
    *	values: days,weeks,months<br/>
    */
    durationUnit?: string;
    financeInfo?: FinanceInfo;
    goals?: Goals;
    info?: Info;
    orgId?: string;
    parentId?: string;
    plannedBudget?: Budget;
    plannedEndDate?: Date;
    plannedStartDate?: Date;
    plannedSubBudget?: Budget;
    position?: number;
    projectId?: string;
    role?: ProjectRole;
    status?: string;
    subTasks?: Task[];
    taskId?: string;
    type?: string;
}
